package com.example.a8_bitinvader;

import androidx.appcompat.app.AppCompatActivity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.ImageView;
import android.widget.Button;
import android.content.Context;
import android.media.AudioManager;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Toast;
import java.util.Timer;
import java.util.TimerTask;
import android.os.Handler;

public class MainActivity extends AppCompatActivity {

    Animation animation;
    boolean play;

    /**
     * Displays the menu and checks for user input to click play
     * @param savedInstanceState The cached state of the game
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_main);

        // the if statement below hides the action bar
        // https://www.geeksforgeeks.org/different-ways-to-hide-action-bar-in-android-with-examples/
        if (getSupportActionBar() != null) {
            getSupportActionBar().hide();
        }


        // initalizes 8-bit Invaders Logo

        ImageView logo = (ImageView) findViewById(R.id.image_logo);
        logo.setImageResource(R.drawable.logobit);

        // Creates new Intent and starts GameActivity if 'play' is pressed on MainActivity screen.
        findViewById(R.id.play_button).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // animation = AnimationUtils.loadAnimation(getApplicationContext(), R.anim.slide_animation);
                // logo.startAnimation(animation);
                startActivity(new Intent(MainActivity.this, GameActivity.class));
                play = true;
            }
        });

        // Creates new Intent and Mutes Device Audio if mute button is pressed on MainActivity screen
        // Reference: https://www.youtube.com/watch?v=_Klq62-me8s&ab_channel=AppleCoders
        // Reference: https://developer.android.com/reference/android/media/MediaPlayer
        findViewById(R.id.mute_button).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // Declare an audio manager
                AudioManager audioManager = (AudioManager)getSystemService(Context.AUDIO_SERVICE);
                // ADJUST_MUTE => mutes the device
                // FLAG_SHOW_UI => Show changes made to the volume bar
                audioManager.adjustVolume (AudioManager.ADJUST_MUTE, AudioManager.FLAG_SHOW_UI);

            }

        });


        // Creates new Intent and stars LeaderboardView if the leaderboard button is pressed on the MainActivity Screen
        // As of 4/14 12:51 AM, this is not implemented with LeaderboardView -- Krish Shah

        findViewById(R.id.leaderboard_button).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                openPopUpWindow();
            }
        });


        //Code to show the toast every 5 seconds. For Preliminary Issue: Repeated event
        Timer timer = new Timer();
        Context context = getApplicationContext();
        CharSequence text = "Hello toast!";
        int duration = 5000;

        timer.schedule(new TimerTask() {

            @Override
            public void run() {
                runOnUiThread(new Runnable() {

                    @Override
                    public void run() {
                        final Toast toast = Toast.makeText(context, text, Toast.LENGTH_SHORT);
                        toast.show();
                        Handler handler = new Handler();
                        handler.postDelayed(new Runnable() {

                            @Override
                            public void run() {
                                toast.cancel();
                            }
                        }, duration);

                    }
                });
            }
        }, 0, duration);
        }

    private void openPopUpWindow() {
        Intent popupwindow = new Intent(MainActivity.this, PopUpWindow.class);
        startActivity(popupwindow);
    }

    /**
     * Start the game
     */
    @Override
    protected void onStart() {
        super.onStart();
    }

    /**
     * Resume the game
     */
    @Override
    protected void onResume() {
        super.onResume();
    }

    /**
     * Pause the game
     */
    @Override
    protected void onPause() {
        super.onPause();
    }

    /**
     * Stop the game
     */
    @Override
    protected void onStop() {
        super.onStop();
    }

    /**
     * Destroy the sprite
     */
    @Override
    protected void onDestroy() {
        super.onDestroy();
    }

    /**
     * Restart the game
     */
    @Override
    protected void onRestart() {
        super.onRestart();
    }

    @Override
    public void onBackPressed() {

        // Call super.onBackPressed() to perform default back button behavior
        super.onBackPressed();

    }


}